function [ out ] = BGConv ( A, B )
% BGConv convolves two joint photon number distributions, A and B
% e.g. A is the source photons statistics, B is the
% background photon statistics --> C is the statistics of A with background B

% Creator: Andy Worsley
% Dept. of Physics, Univeristy of Oxford
% March 2008

% INPUT
% A - the photon statistics of the source
% B - the photon statistics of the background

% OUTPUT
% C - the photons statistics of the source convolved with background

% --- ERRORS --- 
% - A or B not square
if or(size(A,1)~=size(A,2),size(B,1)~=size(B,2))
    error('Matrices must be square');
end
% - size A =/= size B
if size(A,1)~=size(B,1)
    error('Matrices must be the same size');
end
% --------------


S = size(A,2); % Finding the size of the problem

out = zeros(S,S);
C = zeros(S,S);

% Compute the convolution using the convolution theorem
C = abs(ifft2(fft2(A).*fft2(B)));

out = C;